==> haskell-src-meta-0.8.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.0.1
id: haskell-src-meta-0.8.0.1-IUPw27EAdIRBr9yW4wSCQz
key: haskell-src-meta-0.8.0.1-IUPw27EAdIRBr9yW4wSCQz
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
abi: 0d3c89ecd490cb0c61eebb1d2d10bbf2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-src-meta-0.8.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-src-meta-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/haskell-src-meta-0.8.0.1
hs-libraries: HShaskell-src-meta-0.8.0.1-IUPw27EAdIRBr9yW4wSCQz
depends:
    base-4.10.1.0 haskell-src-exts-1.19.1-6osooW3lbE1BgbYPFRxpEo
    pretty-1.1.3.3 syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    template-haskell-2.12.0.0 th-orphans-0.13.4-F3iHhJ4ImhXEalHlf7foa7
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             haskell-src-exts-1.19.1-6osooW3lbE1BgbYPFRxpEo=cb2a6ec7ba5934be83d0a587eb139bd6
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-orphans-0.13.4-F3iHhJ4ImhXEalHlf7foa7=f22aad40e530dfcab60ee373468c11c9
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.0.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.0.1
id: haskell-src-meta-0.8.0.1-m74yAGfIy84FL2oDJ0unC
key: haskell-src-meta-0.8.0.1-m74yAGfIy84FL2oDJ0unC
license: BSD3
copyright: (c) Matt Morrow
maintainer: Ben Millwood <haskell@benmachine.co.uk>
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
author: Matt Morrow
exposed: True
indefinite: False
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
abi: 0b770d99d7a123bd788abdae1027c035
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-src-meta-0.8.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/haskell-src-meta-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/haskell-src-meta-0.8.0.1
hs-libraries: HShaskell-src-meta-0.8.0.1-m74yAGfIy84FL2oDJ0unC
depends:
    base-4.10.1.0 haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp
    pretty-1.1.3.3 syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    template-haskell-2.12.0.0 th-orphans-0.13.4-LwqqRiMLrtE3AAHk7YUFBx
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             haskell-src-exts-1.19.1-BZeaHhmzJaBBBpRWYqrwzp=9e7d1f47a4d57e9fb92fbdd8cc305af5
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=06df45b1c27c5cef935930b2f87d2689
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-orphans-0.13.4-LwqqRiMLrtE3AAHk7YUFBx=777d7f5f09801fa37bb7368c458acc71
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
